@@ -835,8 +835,6 @@ pub fn get_args(version: &str) -> ArgMatches {
                         .long("output")
                         .help("Sets target directory or use a costume file name for a single input")
                         .takes_value(true)
-                        .required(true)
-                        .default_value("SEGUL-Split")
                         .value_name("STRING"),
                 )
                 .arg(
@@ -883,12 +881,29 @@ pub fn get_args(version: &str) -> ArgMatches {
                         .possible_values(&["dna", "aa", "ignore"]),
                 )
                 .arg(
-                    Arg::with_name("partition")
-                        .long("partition")
+                    Arg::with_name("input-partition")
+                        .short("-I")
+                        .long("input-partition")
                         .help("Input sequence partitions")
                         .takes_value(true)
                         .required(true)
                         .value_name("PARTITION-PATH"),
+                )
+                .arg(
+                    Arg::with_name("partition")
+                        .short("-p")
+                        .long("part")
+                        .help("Sets partition format")
+                        .takes_value(true)
+                        .value_name("PART-FORMAT")
+                        .possible_values(&["nexus", "raxml"]),
+                )
+                .arg(
+                    Arg::with_name("prefix")
+                        .long("prefix")
+                        .help("Add prefix to output file names")
+                        .takes_value(true)
+                        .value_name("STRING"),
                 ),
         )
         .get_matches()
