@@ -75,7 +75,8 @@ impl<'a> Id<'a> {
         let mut rec = IdRecords::new(fstem, ids.len());
         let (seq, _) = Sequence::new(file, self.datatype).get(self.input_fmt);
         ids.iter().for_each(|id| {
-            rec.records.push(seq.contains_key(id));
+            let is_id_present = seq.contains_key(id);
+            rec.records.push(is_id_present);
         });
         rec
     }
