@@ -1,20 +1,20 @@
 // A module for sequence statistics.
-// use std::collections::BTreeMap;
 
 use std::path::{Path, PathBuf};
 use std::sync::mpsc::channel;
 
+use indexmap::IndexSet;
 use rayon::prelude::*;
 
 use crate::helper::finder::IDs;
 use crate::helper::sequence::Sequence;
-use crate::helper::stats::{CharSummary, Chars, Completeness, SiteSummary, Sites};
+use crate::helper::stats::{CharSummary, Chars, Completeness, SiteSummary, Sites, Taxa};
 use crate::helper::types::{DataType, InputFmt};
 use crate::helper::utils;
 use crate::writer::summary::{CsvWriter, SummaryWriter};
 
 pub struct SeqStats<'a> {
-    input_format: &'a InputFmt,
+    input_fmt: &'a InputFmt,
     output: &'a Path,
     datatype: &'a DataType,
     ntax: usize,
@@ -23,13 +23,13 @@ pub struct SeqStats<'a> {
 
 impl<'a> SeqStats<'a> {
     pub fn new(
-        input_format: &'a InputFmt,
+        input_fmt: &'a InputFmt,
         output: &'a Path,
         interval: usize,
         datatype: &'a DataType,
     ) -> Self {
         Self {
-            input_format,
+            input_fmt,
             output,
             ntax: 0,
             interval,
@@ -37,30 +37,31 @@ impl<'a> SeqStats<'a> {
         }
     }
 
-    pub fn get_stats_dir(&mut self, files: &[PathBuf]) {
+    pub fn get_stats_all(&mut self, files: &[PathBuf], prefix: &Option<String>) {
         self.check_datatype();
         let spin = utils::set_spinner();
         spin.set_message("Indexing alignments...");
-        self.get_ntax(files);
-        spin.set_message("Computing summary stats...");
-        let mut stats: Vec<(Sites, Chars)> = self.par_get_stats(files);
+        let ids = self.get_id(files);
+        self.ntax = ids.len();
+        spin.set_message("Computing alignment stats...");
+        let mut stats: Vec<(Sites, Chars, Taxa)> = self.par_get_stats(files);
         stats.sort_by(|a, b| alphanumeric_sort::compare_path(&a.0.path, &b.0.path));
         let (sites, dna, complete) = self.get_summary_dna(&stats);
         spin.finish_with_message("Finished computing summary stats!\n");
         let sum = SummaryWriter::new(&sites, &dna, &complete, self.datatype);
         sum.print_summary().expect("Failed writing to stdout");
-        CsvWriter::new(self.output, self.datatype)
-            .write_summary_dir(&stats)
+        let csv = CsvWriter::new(self.output, prefix, self.datatype, &stats);
+        csv.write_taxon_summary(&ids)
+            .expect("Failed writing a taxon stats file");
+        csv.write_locus_summary()
             .expect("Failed writing a per locus csv file");
     }
 
-    fn get_ntax(&mut self, files: &[PathBuf]) {
-        self.ntax = IDs::new(files, self.input_format, self.datatype)
-            .get_id_unique()
-            .len();
+    fn get_id(&mut self, files: &[PathBuf]) -> IndexSet<String> {
+        IDs::new(files, self.input_fmt, self.datatype).get_id_unique()
     }
 
-    fn par_get_stats(&self, files: &[PathBuf]) -> Vec<(Sites, Chars)> {
+    fn par_get_stats(&self, files: &[PathBuf]) -> Vec<(Sites, Chars, Taxa)> {
         let (send, rec) = channel();
         files.par_iter().for_each_with(send, |s, file| {
             s.send(self.get_stats(file)).unwrap();
@@ -74,20 +75,22 @@ impl<'a> SeqStats<'a> {
         }
     }
 
-    fn get_stats(&self, path: &Path) -> (Sites, Chars) {
+    fn get_stats(&self, path: &Path) -> (Sites, Chars, Taxa) {
         let aln = Sequence::new(path, self.datatype);
-        let (matrix, header) = aln.get_alignment(self.input_format);
+        let (matrix, header) = aln.get_alignment(self.input_fmt);
         let mut dna = Chars::new();
         dna.count_chars(&matrix, &header);
         let mut sites = Sites::new();
         sites.get_stats(path, &matrix, self.datatype);
+        let mut taxa = Taxa::new();
+        taxa.summarize_taxa(&matrix);
 
-        (sites, dna)
+        (sites, dna, taxa)
     }
 
     fn get_summary_dna(
         &self,
-        stats: &[(Sites, Chars)],
+        stats: &[(Sites, Chars, Taxa)],
     ) -> (SiteSummary, CharSummary, Completeness) {
         let (sites, dna): (Vec<Sites>, Vec<Chars>) =
             stats.par_iter().map(|p| (p.0.clone(), p.1.clone())).unzip();
