@@ -1,6 +1,8 @@
 pub mod alphabet;
+pub mod filenames;
 pub mod finder;
 pub mod sequence;
 pub mod stats;
+pub mod translation;
 pub mod types;
 pub mod utils;
